@@ -55,7 +55,7 @@ class TRMaid(object):
             )
 
         # config
-        self.conf = yaml.load(open(CONF_FILE_FULL))
+        self.conf = yaml.load(open(config_file))
         general = self.conf.get('general', {})
         transmission = self.conf.get('transmission', {})
 
@@ -330,7 +330,6 @@ class TRMaid(object):
             # Text / Strings
             "cookies",
             "download-dir",
-            "metainfo",
         ]
         for key in keys:
             value = self.conf.get(section, {}).get(subsection, {}).get(key)
@@ -373,7 +372,10 @@ class TRMaid(object):
                 req['location'] = location
 
         if 'trackerAdd' in conf:
-            req['trackerAdd'] = conf['trackerAdd']
+            existing = map(lambda x:x['announce'], tor['trackers'])
+            missing = [t for t in conf['trackerAdd'] if t not in existing]
+            if missing:
+                req['trackerAdd'] = missing
 
         return req
 
